@@ -85,10 +85,10 @@ class Lockdown(object):
         ''' Return the attribute of the namespace or None '''
         return self.___glob[attr]
         
-    def _lockdown_gen_hmac(self, ctext):
-        ''' Generate an HMAC from cipher text '''
+    def _lockdown_gen_hmac(self, ctext, iv):
+        ''' Generate an HMAC from cipher text and its IV '''
         hmac = HMAC.new(self.___keys['HMAC'])
-        hmac.update(ctext)
+        hmac.update(iv + ctext)
         # Returns 16 bytes by default.
         return hmac.digest()
 
@@ -114,7 +114,7 @@ class Lockdown(object):
             plain = input_f.read()
         ctext = self.___cipher.encrypt(plain)
         self.___cipher = None
-        hmac = self._lockdown_gen_hmac(ctext)
+        hmac = self._lockdown_gen_hmac(ctext, iv)
         # 8 byte HMAC salt + 16 byte HMAC + 8 byte AES salt + 8 byte IV
         prefix = self.___salts['HMAC'] + hmac + self.___salts['AES'] + iv
         return prefix + ctext
@@ -131,9 +131,8 @@ class Lockdown(object):
         ctext = ftext[40:]
         self._lockdown_setup_cipher(salts=self.___salts, iv=iv)
         ptext = self.___cipher.decrypt(ctext)
-        check_hmac = HMAC.new(self.___keys['HMAC'])
-        check_hmac.update(ctext)
-        if check_hmac.digest() != hmac:
+        hmac_digest = self._lockdown_gen_hmac(ctext, iv)
+        if hmac_digest != hmac:
             raise ValueError('HMAC didnt match.\n'
                 'Someone could be doing something nasty.')
         self.___cipher = None
